Struct teloxide_core::payloads::AnswerShippingQuery
source · [−]pub struct AnswerShippingQuery {
pub shipping_query_id: String,
pub ok: bool,
pub shipping_options: Option<Vec<ShippingOption>>,
pub error_message: Option<String>,
}Expand description
If you sent an invoice requesting a shipping address and the parameter is_flexible was specified, the Bot API will send an Update with a shipping_query field to the bot. Use this method to reply to shipping queries. On success, True is returned.
Fields
shipping_query_id: StringUnique identifier for the query to be answered
ok: boolSpecify True if delivery to the specified address is possible and False if there are any problems (for example, if delivery to the specified address is not possible)
shipping_options: Option<Vec<ShippingOption>>Required if ok is True. A JSON-serialized array of available shipping options.
error_message: Option<String>Required if ok is False. Error message in human readable form that explains why it is impossible to complete the order (e.g. ‘Sorry, delivery to your desired address is unavailable’). Telegram will display this message to the user.
Implementations