Struct teloxide_core::payloads::AnswerWebAppQuery
source · [−]pub struct AnswerWebAppQuery {
pub web_app_query_id: String,
pub result: InlineQueryResult,
}Expand description
Use this method to set the result of an interaction with a Web App and send a corresponding message on behalf of the user to the chat from which the query originated.
Fields
web_app_query_id: StringUnique identifier for the query to be answered
result: InlineQueryResultA JSON-serialized object describing the message to be sent
Implementations
sourceimpl AnswerWebAppQuery
impl AnswerWebAppQuery
pub fn new(
web_app_query_id: impl Into<String>,
result: InlineQueryResult
) -> Self