Struct teloxide_core::payloads::CreateNewStickerSet
source · [−]pub struct CreateNewStickerSet {
pub user_id: UserId,
pub name: String,
pub title: String,
pub sticker: InputSticker,
pub emojis: String,
pub sticker_type: Option<StickerType>,
pub mask_position: Option<MaskPosition>,
}Expand description
Use this method to create a new sticker set owned by a user. The bot will be able to edit the sticker set thus created. You must use exactly one of the fields png_sticker or tgs_sticker. Returns True on success.
Fields
user_id: UserIdUser identifier of sticker file owner
name: StringShort name of sticker set, to be used in t.me/addstickers/ URLs (e.g., animals). Can contain only english letters, digits and underscores. Must begin with a letter, can’t contain consecutive underscores and must end in “_by_
title: StringSticker set title, 1-64 characters
sticker: InputStickerPNG image, TGS animation or WEBM video with the sticker, must be up to 512 kilobytes in size, dimensions must not exceed 512px, and either width or height must be exactly 512px. Pass a file_id as a String to send a file that already exists on the Telegram servers, pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one using multipart/form-data. More info on Sending Files »
emojis: StringOne or more emoji corresponding to the sticker
sticker_type: Option<StickerType>Type of stickers in the set, pass “regular” or “mask”. Custom emoji sticker sets can’t be created via the Bot API at the moment. By default, a regular sticker set is created.
mask_position: Option<MaskPosition>A JSON-serialized object for position where the mask should be placed on faces
Implementations