pub struct DeclineChatJoinRequest {
pub chat_id: Recipient,
pub user_id: UserId,
}Expand description
Use this method to decline a chat join request. The bot must be an administrator in the chat for this to work and must have the can_invite_users administrator right. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
user_id: UserIdUnique identifier of the target user
Implementations