Struct teloxide_core::payloads::DeleteChatStickerSet
source · [−]pub struct DeleteChatStickerSet {
pub chat_id: Recipient,
}Expand description
Use this method to delete a group sticker set from a supergroup. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Use the field can_set_sticker_set optionally returned in GetChat requests to check if the bot can use this method. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
Implementations