pub struct EditChatSubscriptionInviteLink {
pub chat_id: Recipient,
pub invite_link: String,
pub name: Option<String>,
}Expand description
Use this method to edit a subscription invite link created by the bot. The bot must have the can_invite_users administrator rights. Returns the edited invite link as a ChatInviteLink object.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
invite_link: StringThe invite link to edit
name: Option<String>Invite link name; 0-32 characters
Implementations