Struct teloxide_core::payloads::EditMessageCaption
source · [−]pub struct EditMessageCaption {
pub chat_id: Recipient,
pub message_id: MessageId,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit captions of messages. On success, the edited Message is returned.
See also: EditMessageCaptionInline
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername).
message_id: MessageIdIdentifier of the message to edit
caption: Option<String>New caption of the message, 0-1024 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be specified instead of parse_mode
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations