pub struct EditMessageCaptionInline {
pub inline_message_id: String,
pub business_connection_id: Option<BusinessConnectionId>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit captions of messages. On success, True is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within 48 hours from the time they were sent.
See also: EditMessageCaption
Fields
inline_message_id: StringIdentifier of the inline message
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
caption: Option<String>New caption of the message, 0-1024 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be specified instead of parse_mode
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations