pub struct EditMessageMediaInline {
pub inline_message_id: String,
pub media: InputMedia,
pub business_connection_id: Option<BusinessConnectionId>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit animation, audio, document, photo, or video messages, or to add media to text messages. If a message is a part of a message album, then it can be edited only to a photo or a video. Otherwise, message type can be changed arbitrarily. When inline message is edited, new file can’t be uploaded. Use previously uploaded file via its file_id or specify a URL. On success, True is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within 48 hours from the time they were sent.
See also: EditMessageMedia
Fields
inline_message_id: StringIdentifier of the inline message
media: InputMediaA JSON-serialized object for a new media content of the message
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations
Sourceimpl EditMessageMediaInline
impl EditMessageMediaInline
pub fn new(inline_message_id: impl Into<String>, media: InputMedia) -> Self