pub struct EditMessageReplyMarkupInline {
pub inline_message_id: String,
pub business_connection_id: Option<BusinessConnectionId>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit only the reply markup of messages. On success, True is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within 48 hours from the time they were sent.
See also: EditMessageReplyMarkup
Fields
inline_message_id: StringIdentifier of the inline message
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations