pub struct EditMessageTextInline {
pub inline_message_id: String,
pub text: String,
pub business_connection_id: Option<BusinessConnectionId>,
pub parse_mode: Option<ParseMode>,
pub entities: Option<Vec<MessageEntity>>,
pub disable_web_page_preview: Option<bool>,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to edit text and games messages. On success, True is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within 48 hours from the time they were sent.
See also: EditMessageText
Fields
inline_message_id: StringIdentifier of the inline message
text: StringNew text of the message, 1-4096 characters after entities parsing
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
entities: Option<Vec<MessageEntity>>List of special entities that appear in message text, which can be specified instead of parse_mode
disable_web_page_preview: Option<bool>Disables link previews for links in this message
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations