pub struct EditUserStarSubscription {
pub user_id: UserId,
pub telegram_payment_charge_id: TelegramTransactionId,
pub is_canceled: bool,
}Expand description
Allows the bot to cancel or re-enable extension of a subscription paid in Telegram Stars. Returns True on success.
Fields
user_id: UserIdIdentifier of the user whose subscription will be edited
telegram_payment_charge_id: TelegramTransactionIdTelegram payment identifier for the subscription
is_canceled: boolPass true to cancel extension of the user subscription; the subscription must be active up to the end of the current subscription period. Pass false to allow the user to re-enable a subscription that was previously canceled by the bot.
Implementations
Sourceimpl EditUserStarSubscription
impl EditUserStarSubscription
pub fn new( user_id: UserId, telegram_payment_charge_id: TelegramTransactionId, is_canceled: bool, ) -> Self