Struct teloxide_core::payloads::ExportChatInviteLink
source · [−]pub struct ExportChatInviteLink {
pub chat_id: Recipient,
}Expand description
Use this method to generate a new invite link for a chat; any previously generated link is revoked. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Returns the new invite link as String on success.
Note: Each administrator in a chat generates their own invite links. Bots can’t use invite links generated by other administrators. If you want your bot to work with invite links, it will need to generate its own link using exportChatInviteLink — after this the link will become available to the bot via the getChat method. If your bot needs to generate a new invite link replacing its previous one, use exportChatInviteLink again.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
Implementations