pub struct ForwardMessages {
pub chat_id: Recipient,
pub from_chat_id: Recipient,
pub message_ids: Vec<MessageId>,
pub message_thread_id: Option<ThreadId>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
}Expand description
Use this method to forward multiple messages of any kind. If some of the specified messages can’t be found or forwarded, they are skipped. Service messages and messages with protected content can’t be forwarded. Album grouping is kept for forwarded messages. On success, an array of MessageId of the sent messages is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
from_chat_id: RecipientUnique identifier for the chat where the original message was sent (or channel username in the format @channelusername)
message_ids: Vec<MessageId>A JSON-serialized list of 1-100 identifiers of messages in the chat from_chat_id to forward. The identifiers must be specified in a strictly increasing order.
message_thread_id: Option<ThreadId>Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
Implementations