Struct teloxide_core::payloads::GetChatMember
source · [−]Expand description
Use this method to get information about a member of a chat. Returns a ChatMember object on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
user_id: UserIdUnique identifier of the target user
Implementations