pub struct GetChatMemberCount {
pub chat_id: Recipient,
}Expand description
Use this method to get the number of members in a chat. Returns Int on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
Implementations