Struct teloxide_core::payloads::GetChatMenuButton
source · [−]Expand description
Use this method to get the current value of the bot’s menu button in a private chat, or the default menu button.
Fields
chat_id: Option<ChatId>Unique identifier for the target private chat. If not specified, default bot’s menu button will be returned
Implementations