Struct teloxide_core::payloads::PinChatMessage
source · [−]pub struct PinChatMessage {
pub chat_id: Recipient,
pub message_id: MessageId,
pub disable_notification: Option<bool>,
}Expand description
Use this method to pin a message in a group, a supergroup, or a channel. The bot must be an administrator in the chat for this to work and must have the ‘can_pin_messages’ admin right in the supergroup or ‘can_edit_messages’ admin right in the channel. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_id: MessageIdIdentifier of a message to pin
disable_notification: Option<bool>Pass True, if it is not necessary to send a notification to all chat members about the new pinned message. Notifications are always disabled in channels.
Implementations