logo
pub struct PromoteChatMember {
Show 13 fields pub chat_id: Recipient, pub user_id: UserId, pub is_anonymous: Option<bool>, pub can_manage_chat: Option<bool>, pub can_change_info: Option<bool>, pub can_post_messages: Option<bool>, pub can_edit_messages: Option<bool>, pub can_delete_messages: Option<bool>, pub can_manage_video_chats: Option<bool>, pub can_invite_users: Option<bool>, pub can_restrict_members: Option<bool>, pub can_pin_messages: Option<bool>, pub can_promote_members: Option<bool>,
}
Use this method to promote or demote a user in a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Pass False for all boolean parameters to demote a user. Returns True on success.

Fields

chat_id: Recipient

Unique identifier for the target chat or username of the target channel (in the format @channelusername)

user_id: UserId

Unique identifier of the target user

is_anonymous: Option<bool>

Pass True, if the administrator’s presence in the chat is hidden

can_manage_chat: Option<bool>

Pass True, if the administrator can access the chat event log, chat statistics, message statistics in channels, see channel members, see anonymous administrators in supergroups and ignore slow mode. Implied by any other administrator privilege

can_change_info: Option<bool>

Pass True, if the administrator can change chat title, photo and other settings

can_post_messages: Option<bool>

Pass True, if the administrator can create channel posts, channels only

can_edit_messages: Option<bool>

Pass True, if the administrator can edit messages of other users and can pin messages, channels only

can_delete_messages: Option<bool>

Pass True, if the administrator can delete messages of other users

can_manage_video_chats: Option<bool>

Pass True, if the administrator can manage video chats, supergroups only

can_invite_users: Option<bool>

Pass True, if the administrator can invite new users to the chat

can_restrict_members: Option<bool>

Pass True, if the administrator can restrict, ban or unban chat members

can_pin_messages: Option<bool>

Pass True, if the administrator can pin messages, supergroups only

can_promote_members: Option<bool>

Pass True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that he has promoted, directly or indirectly (promoted by administrators that were appointed by him)

Implementations