pub struct ReadBusinessMessage {
pub business_connection_id: BusinessConnectionId,
pub chat_id: ChatId,
pub message_id: MessageId,
}Expand description
Marks incoming message as read on behalf of a business account. Requires the can_read_messages business bot right. Returns true on success.
Fields
business_connection_id: BusinessConnectionIdUnique identifier of the business connection on behalf of which to read the message
chat_id: ChatIdUnique identifier of the chat in which the message was received. The chat must have been active in the last 24 hours
message_id: MessageIdUnique identifier of the message to mark as read
Implementations