pub struct RemoveUserVerification {
pub user_id: UserId,
}Expand description
Removes verification from a user who is currently verified on behalf of the organization represented by the bot. Returns true on success.
Fields
user_id: UserIdUnique identifier of the target user
Implementations