pub struct RevokeChatInviteLink {
pub chat_id: Recipient,
pub invite_link: String,
}Expand description
Use this method to revoke an invite link created by the bot. If the primary link is revoked, a new link is automatically generated. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Returns the revoked invite link as ChatInviteLink object.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
invite_link: StringThe invite link to revoke
Implementations