Struct teloxide_core::payloads::SendContact
source · [−]pub struct SendContact {
pub chat_id: Recipient,
pub phone_number: String,
pub first_name: String,
pub last_name: Option<String>,
pub vcard: Option<String>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub reply_to_message_id: Option<MessageId>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send phone contacts. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
phone_number: StringContact’s phone number
first_name: StringContact’s first name
last_name: Option<String>Contact’s last name
vcard: Option<String>Additional data about the contact in the form of a vCard, 0-2048 bytes
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
reply_to_message_id: Option<MessageId>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Implementations