pub struct SendGift {
pub user_id: UserId,
pub gift_id: GiftId,
pub pay_for_upgrade: Option<bool>,
pub text: Option<String>,
pub text_parse_mode: Option<ParseMode>,
pub text_entities: Option<Vec<MessageEntity>>,
}Expand description
Sends a gift to the given user. The gift can’t be converted to Telegram Stars by the user. Returns True on success.
See also: SendGiftChat
Fields
user_id: UserIdUnique identifier of the target user that will receive the gift
gift_id: GiftIdIdentifier of the gift
pay_for_upgrade: Option<bool>Pass true to pay for the gift upgrade from the bot’s balance, thereby making the upgrade free for the receiver
text: Option<String>Text that will be shown along with the gift; 0-255 characters
text_parse_mode: Option<ParseMode>Mode for parsing entities in the text. See formatting options for more details. Entities other than “bold”, “italic”, “underline”, “strikethrough”, “spoiler”, and “custom_emoji” are ignored
text_entities: Option<Vec<MessageEntity>>List of special entities that appear in the gift text. It can be specified instead of text_parse_mode. Entities other than “bold”, “italic”, “underline”, “strikethrough”, “spoiler”, and “custom_emoji” are ignored.
Implementations