Struct teloxide_core::payloads::SendPoll
source · [−]pub struct SendPoll {Show 18 fields
pub chat_id: Recipient,
pub question: String,
pub options: Vec<String>,
pub is_anonymous: Option<bool>,
pub type_: Option<PollType>,
pub allows_multiple_answers: Option<bool>,
pub correct_option_id: Option<u8>,
pub explanation: Option<String>,
pub explanation_parse_mode: Option<ParseMode>,
pub explanation_entities: Option<Vec<MessageEntity>>,
pub open_period: Option<u16>,
pub close_date: Option<DateTime<Utc>>,
pub is_closed: Option<bool>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub reply_to_message_id: Option<MessageId>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send phone contacts. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
question: StringPoll question, 1-300 characters
options: Vec<String>A JSON-serialized list of answer options, 2-10 strings 1-100 characters each
is_anonymous: Option<bool>True, if the poll needs to be anonymous, defaults to True
type_: Option<PollType>Poll type, “quiz” or “regular”, defaults to “regular”
allows_multiple_answers: Option<bool>True, if the poll allows multiple answers, ignored for polls in quiz mode, defaults to False
correct_option_id: Option<u8>0-based identifier of the correct answer option, required for polls in quiz mode
explanation: Option<String>Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 characters with at most 2 line feeds after entities parsing
explanation_parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
explanation_entities: Option<Vec<MessageEntity>>List of special entities that appear in the poll explanation, which can be specified instead of parse_mode
open_period: Option<u16>Amount of time in seconds the poll will be active after creation, 5-600. Can’t be used together with close_date.
close_date: Option<DateTime<Utc>>Point in time (Unix timestamp) when the poll will be automatically closed. Must be at least 5 and no more than 600 seconds in the future. Can’t be used together with open_period.
is_closed: Option<bool>Pass True, if the poll needs to be immediately closed. This can be useful for poll preview.
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
reply_to_message_id: Option<MessageId>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Implementations