logo
pub struct SendSticker {
    pub chat_id: Recipient,
    pub sticker: InputFile,
    pub disable_notification: Option<bool>,
    pub protect_content: Option<bool>,
    pub reply_to_message_id: Option<i32>,
    pub allow_sending_without_reply: Option<bool>,
    pub reply_markup: Option<ReplyMarkup>,
}
Use this method to send static .WEBP or animated .TGS stickers. On success, the sent Message is returned.

Fields

chat_id: Recipient

Unique identifier for the target chat or username of the target channel (in the format @channelusername).

sticker: InputFile

Sticker to send. Pass a file_id as String to send a photo that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get a photo from the Internet, or upload a new photo using multipart/form-data. More info on Sending Files »

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

protect_content: Option<bool>

Protects the contents of sent messages from forwarding and saving

reply_to_message_id: Option<i32>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

Implementations