pub struct SetChatAdministratorCustomTitle {
pub chat_id: Recipient,
pub user_id: UserId,
pub custom_title: String,
}Expand description
Use this method to set a custom title for an administrator in a supergroup promoted by the bot. Returns _True_on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
user_id: UserIdUnique identifier of the target user
custom_title: StringNew custom title for the administrator; 0-16 characters, emoji are not allowed
Implementations