Struct teloxide_core::payloads::SetChatPermissions
source · [−]pub struct SetChatPermissions {
pub chat_id: Recipient,
pub permissions: ChatPermissions,
}Expand description
Use this method to set default chat permissions for all members. The bot must be an administrator in the group or a supergroup for this to work and must have the can_restrict_members admin rights. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
permissions: ChatPermissionsNew default chat permissions
Implementations
sourceimpl SetChatPermissions
impl SetChatPermissions
pub fn new(chat_id: impl Into<Recipient>, permissions: ChatPermissions) -> Self