Struct teloxide_core::payloads::SetChatPhoto
source · [−]Expand description
Use this method to set a new profile photo for the chat. Photos can’t be changed for private chats. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
photo: InputFileNew chat photo, uploaded using multipart/form-data
Implementations