Struct teloxide_core::payloads::SetGameScore
source · [−]pub struct SetGameScore {
pub user_id: UserId,
pub score: u64,
pub chat_id: u32,
pub message_id: MessageId,
pub force: Option<bool>,
pub disable_edit_message: Option<bool>,
}Expand description
Use this method to set the score of the specified user in a game. On success, returns the edited Message. Returns an error, if the new score is not greater than the user’s current score in the chat and force is False.
See also: SetGameScoreInline
Fields
user_id: UserIdUser identifier
score: u64New score
chat_id: u32Unique identifier for the target chat
message_id: MessageIdIdentifier of the message to edit
force: Option<bool>Pass True, if the high score is allowed to decrease. This can be useful when fixing mistakes or banning cheaters
disable_edit_message: Option<bool>Pass True, if the game message should not be automatically edited to include the current scoreboard
Implementations