Struct teloxide_core::payloads::SetGameScoreInline
source · [−]pub struct SetGameScoreInline {
pub user_id: UserId,
pub score: u64,
pub inline_message_id: String,
pub force: Option<bool>,
pub disable_edit_message: Option<bool>,
}Expand description
Use this method to set the score of the specified user in a game. On success, returns True. Returns an error, if the new score is not greater than the user’s current score in the chat and force is False.
See also: SetGameScore
Fields
user_id: UserIdUser identifier
score: u64New score
inline_message_id: StringIdentifier of the inline message
force: Option<bool>Pass True, if the high score is allowed to decrease. This can be useful when fixing mistakes or banning cheaters
disable_edit_message: Option<bool>Pass True, if the game message should not be automatically edited to include the current scoreboard
Implementations