Struct teloxide_core::payloads::SetMyCommands
source · [−]pub struct SetMyCommands {
pub commands: Vec<BotCommand>,
pub scope: Option<BotCommandScope>,
pub language_code: Option<String>,
}Expand description
Use this method to change the list of the bot’s commands. Returns True on success.
Fields
commands: Vec<BotCommand>A JSON-serialized list of bot commands to be set as the list of the bot’s commands. At most 100 commands can be specified.
scope: Option<BotCommandScope>A JSON-serialized object, describing scope of users for which the commands are relevant. Defaults to BotCommandScopeDefault.
language_code: Option<String>A two-letter ISO 639-1 language code. If empty, commands will be applied to all users from the given scope, for whose language there are no dedicated commands
Implementations
sourceimpl SetMyCommands
impl SetMyCommands
pub fn new(commands: impl IntoIterator<Item = BotCommand>) -> Self