Struct teloxide_core::payloads::SetPassportDataErrors
source · [−]pub struct SetPassportDataErrors {
pub user_id: UserId,
pub errors: Vec<PassportElementError>,
}Expand description
Informs a user that some of the Telegram Passport elements they provided contains errors. The user will not be able to re-submit their Passport to you until the errors are fixed (the contents of the field for which you returned the error must change). Returns True on success.
Use this if the data submitted by the user doesn’t satisfy the standards your service requires for any reason. For example, if a birthday date seems invalid, a submitted document is blurry, a scan shows evidence of tampering, etc. Supply some details in the error message to make sure the user knows how to correct the issues.
Fields
user_id: UserIdUser identifier
errors: Vec<PassportElementError>A JSON-serialized array describing the errors
Implementations
sourceimpl SetPassportDataErrors
impl SetPassportDataErrors
pub fn new(
user_id: UserId,
errors: impl IntoIterator<Item = PassportElementError>
) -> Self