pub struct SetStickerEmojiList {
pub sticker: String,
pub emoji_list: Vec<String>,
}Expand description
Use this method to change the list of emoji assigned to a regular or custom emoji sticker. The sticker must belong to a sticker set created by the bot. Returns True on success.
Fields
sticker: StringFile identifier of the sticker
emoji_list: Vec<String>A JSON-serialized list of 1-20 emoji associated with the sticker
Implementations