Struct teloxide_core::payloads::SetStickerPositionInSet
source · [−]Expand description
Use this method to move a sticker in a set created by the bot to a specific position. Returns True on success.
Fields
sticker: StringFile identifier of the sticker
position: u32New sticker position in the set, zero-based
Implementations