Struct teloxide_core::payloads::SetStickerSetThumb
source · [−]pub struct SetStickerSetThumb {
pub name: String,
pub user_id: UserId,
pub thumb: Option<InputFile>,
}Expand description
Use this method to set the thumbnail of a sticker set. Animated thumbnails can be set for animated sticker sets only. Returns True on success.
Fields
name: StringName of the sticker set
user_id: UserIdUser identifier of sticker file owner
thumb: Option<InputFile>A PNG image with the thumbnail, must be up to 128 kilobytes in size and have width and height exactly 100px, or a TGS animation with the thumbnail up to 32 kilobytes in size; see https://core.telegram.org/animated_stickers#technical-requirements for animated sticker technical requirements. Pass a file_id as a String to send a file that already exists on the Telegram servers, pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one using multipart/form-data. More info on Sending Files ». Animated sticker set thumbnail can’t be uploaded via HTTP URL.
Implementations