pub struct SetUserEmojiStatus {
pub user_id: UserId,
pub emoji_status_custom_emoji_id: Option<CustomEmojiId>,
pub emoji_status_expiration_date: Option<DateTime<Utc>>,
}Expand description
Changes the emoji status for a given user that previously allowed the bot to manage their emoji status via the Mini App method requestEmojiStatusAccess. Returns True on success.
Fields
user_id: UserIdUnique identifier of the target user
emoji_status_custom_emoji_id: Option<CustomEmojiId>Custom emoji identifier of the emoji status to set. Pass an empty string to remove the status
emoji_status_expiration_date: Option<DateTime<Utc>>Expiration date of the emoji status, if any
Implementations