pub struct StopMessageLiveLocation {
pub chat_id: Recipient,
pub message_id: MessageId,
pub business_connection_id: Option<BusinessConnectionId>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to edit live location messages. A location can be edited until its live_period expires or editing is explicitly disabled by a call to StopMessageLiveLocation. On success, the edited Message is returned.
See also: StopMessageLiveLocationInline
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_id: MessageIdIdentifier of the message to edit
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove a reply keyboard or to force a reply from the user. Not supported for messages sent on behalf of a business account.
Implementations