Struct teloxide_core::payloads::StopPoll
source · [−]pub struct StopPoll {
pub chat_id: Recipient,
pub message_id: MessageId,
pub reply_markup: Option<InlineKeyboardMarkup>,
}Expand description
Use this method to stop a poll which was sent by the bot. On success, the stopped Poll with the final results is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername).
message_id: MessageIdIdentifier of the message to edit
reply_markup: Option<InlineKeyboardMarkup>A JSON-serialized object for an inline keyboard.
Implementations