pub struct TransferGift {
pub business_connection_id: BusinessConnectionId,
pub owned_gift_id: OwnedGiftId,
pub new_owner_chat_id: ChatId,
pub star_count: Option<u32>,
}Expand description
Transfers an owned unique gift to another user. Requires the can_transfer_and_upgrade_gifts business bot right. Requires can_transfer_stars business bot right if the transfer is paid. Returns true on success.
Fields
business_connection_id: BusinessConnectionIdUnique identifier of the business connection
owned_gift_id: OwnedGiftIdUnique identifier of the regular gift that should be converted to Telegram Stars
new_owner_chat_id: ChatIdUnique identifier of the chat which will own the gift. The chat must be active in the last 24 hours
star_count: Option<u32>The amount of Telegram Stars that will be paid for the transfer from the business account balance. If positive, then the can_transfer_stars business bot right is required
Implementations
Sourceimpl TransferGift
impl TransferGift
pub fn new( business_connection_id: BusinessConnectionId, owned_gift_id: OwnedGiftId, new_owner_chat_id: impl Into<ChatId>, ) -> Self