logo
pub struct UploadStickerFile {
    pub user_id: UserId,
    pub png_sticker: InputFile,
}
Use this method to upload a .PNG file with a sticker for later use in createNewStickerSet and addStickerToSet methods (can be used multiple times). Returns the uploaded File on success.

Fields

user_id: UserId

User identifier of sticker file owner

png_sticker: InputFile

PNG image with the sticker, must be up to 512 kilobytes in size, dimensions must not exceed 512px, and either width or height must be exactly 512px. More info on Sending Files »

Implementations