pub struct VerifyChat {
pub chat_id: Recipient,
pub custom_description: Option<String>,
}Expand description
Verifies a chat on behalf of the organization which is represented by the bot. Returns true on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel
custom_description: Option<String>Custom description for the verification; 0-70 characters. Must be empty if the organization isn’t allowed to provide a custom verification description.
Implementations