Struct teloxide_core::payloads::EditChatInviteLink
source · [−]pub struct EditChatInviteLink {
pub chat_id: Recipient,
pub invite_link: String,
pub name: Option<String>,
pub expire_date: Option<DateTime<Utc>>,
pub member_limit: Option<u32>,
pub creates_join_request: Option<bool>,
}Expand description
Use this method to edit a non-primary invite link created by the bot. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Returns the edited invite link as a ChatInviteLink object.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
invite_link: StringThe invite link to edit
name: Option<String>Invite link name; 0-32 characters
expire_date: Option<DateTime<Utc>>Point in time (Unix timestamp) when the link will expire
member_limit: Option<u32>Maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999
creates_join_request: Option<bool>True, if users joining the chat via the link need to be approved by chat administrators. If True, member_limit can’t be specified
Implementations