pub struct EditMessageLiveLocation {
pub chat_id: Recipient,
pub message_id: MessageId,
pub latitude: f64,
pub longitude: f64,
pub business_connection_id: Option<BusinessConnectionId>,
pub live_period: Option<LivePeriod>,
pub horizontal_accuracy: Option<f64>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to edit live location messages. A location can be edited until its live_period expires or editing is explicitly disabled by a call to StopMessageLiveLocation. On success, the edited Message is returned.
See also: EditMessageLiveLocationInline
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_id: MessageIdIdentifier of the message to edit
latitude: f64Latitude of new location
longitude: f64Longitude of new location
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message to be edited was sent
live_period: Option<LivePeriod>New period in seconds during which the location can be updated, starting from the message send date. If 0x7FFFFFFF is specified, then the location can be updated forever. Otherwise, the new value must not exceed the current live_period by more than a day, and the live location expiration date must remain within the next 90 days. If not specified, then live_period remains unchanged
horizontal_accuracy: Option<f64>The radius of uncertainty for the location, measured in meters; 0-1500
heading: Option<u16>For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
proximity_alert_radius: Option<u32>For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove a reply keyboard or to force a reply from the user. Not supported for messages sent on behalf of a business account.
Implementations