logo
pub struct EditMessageLiveLocationInline {
    pub inline_message_id: String,
    pub latitude: f64,
    pub longitude: f64,
    pub horizontal_accuracy: Option<f64>,
    pub heading: Option<u16>,
    pub proximity_alert_radius: Option<u32>,
    pub reply_markup: Option<ReplyMarkup>,
}
Use this method to edit live location messages. A location can be edited until its live_period expires or editing is explicitly disabled by a call to StopMessageLiveLocation. On success, True is returned.

See also: EditMessageLiveLocation

Fields

inline_message_id: String

Identifier of the inline message

latitude: f64

Latitude of new location

longitude: f64

Longitude of new location

horizontal_accuracy: Option<f64>

The radius of uncertainty for the location, measured in meters; 0-1500

heading: Option<u16>

For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.

proximity_alert_radius: Option<u32>

For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.

reply_markup: Option<ReplyMarkup>

Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.

Implementations