Struct teloxide_core::payloads::GetChatAdministrators
source · [−]pub struct GetChatAdministrators {
pub chat_id: Recipient,
}Expand description
Use this method to get a list of administrators in a chat. On success, returns an Array of ChatMember objects that contains information about all chat administrators except other bots. If the chat is a group or a supergroup and no administrators were appointed, only the creator will be returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
Implementations