Struct teloxide_core::payloads::LeaveChat
source · [−]pub struct LeaveChat {
pub chat_id: Recipient,
}Expand description
Use this method for your bot to leave a group, supergroup or channel. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
Implementations