logo
pub struct SendGame {
    pub chat_id: u32,
    pub game_short_name: String,
    pub disable_notification: Option<bool>,
    pub protect_content: Option<bool>,
    pub reply_to_message_id: Option<i32>,
    pub allow_sending_without_reply: Option<bool>,
    pub reply_markup: Option<ReplyMarkup>,
}
Use this method to send a game. On success, the sent Message is returned.

Fields

chat_id: u32

Unique identifier for the target chat

game_short_name: String

Short name of the game, serves as the unique identifier for the game. Set up your games via Botfather.

disable_notification: Option<bool>

Sends the message silently. Users will receive a notification with no sound.

protect_content: Option<bool>

Protects the contents of sent messages from forwarding and saving

reply_to_message_id: Option<i32>

If the message is a reply, ID of the original message

allow_sending_without_reply: Option<bool>

Pass True, if the message should be sent even if the specified replied-to message is not found

reply_markup: Option<ReplyMarkup>

A JSON-serialized object for an inline keyboard. If empty, one ‘Play game_title’ button will be shown. If not empty, the first button must launch the game.

Implementations