Struct teloxide_core::payloads::SendLocation
source · [−]pub struct SendLocation {
pub chat_id: Recipient,
pub latitude: f64,
pub longitude: f64,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<u32>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub reply_to_message_id: Option<MessageId>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send point on the map. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
latitude: f64Latitude of the location
longitude: f64Longitude of the location
horizontal_accuracy: Option<f64>The radius of uncertainty for the location, measured in meters; 0-1500
live_period: Option<u32>Period in seconds for which the location will be updated (see Live Locations, should be between 60 and 86400.
heading: Option<u16>For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
proximity_alert_radius: Option<u32>For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
reply_to_message_id: Option<MessageId>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Implementations