Struct teloxide_core::payloads::SendMessage
source · [−]pub struct SendMessage {
pub chat_id: Recipient,
pub text: String,
pub parse_mode: Option<ParseMode>,
pub entities: Option<Vec<MessageEntity>>,
pub disable_web_page_preview: Option<bool>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub reply_to_message_id: Option<MessageId>,
pub allow_sending_without_reply: Option<bool>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send text messages. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
text: StringText of the message to be sent, 1-4096 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
entities: Option<Vec<MessageEntity>>List of special entities that appear in the message text, which can be specified instead of parse_mode
disable_web_page_preview: Option<bool>Disables link previews for links in this message
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
reply_to_message_id: Option<MessageId>If the message is a reply, ID of the original message
allow_sending_without_reply: Option<bool>Pass True, if the message should be sent even if the specified replied-to message is not found
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Implementations