Struct teloxide_core::payloads::SetChatDescription
source · [−]Expand description
Use this method to change the description of a group, a supergroup or a channel. The bot must be an administrator in the chat for this to work and must have the appropriate admin rights. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
description: Option<String>New chat description, 0-255 characters
Implementations