pub struct StopMessageLiveLocationInline {
pub inline_message_id: String,
pub latitude: f64,
pub longitude: f64,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to edit live location messages. A location can be edited until its live_period expires or editing is explicitly disabled by a call to StopMessageLiveLocation. On success, True is returned.
See also: StopMessageLiveLocation
Fields
inline_message_id: StringIdentifier of the inline message
latitude: f64Latitude of new location
longitude: f64Longitude of new location
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
Implementations